@@ -3,29 +3,29 @@ package WWW::Mechanize::Cached;
 use strict;
 use warnings FATAL => 'all';
 
-=head1 NAME
+=head1 Name
 
 WWW::Mechanize::Cached - Cache response to be polite
 
-=head1 VERSION
+=head1 Version
 
-Version 1.30
+Version 1.32
 
-    $Header: /home/cvs/www-mechanize-cached/Cached.pm,v 1.14 2004/03/14 08:52:43 andy Exp $
+    $Header: /home/cvs/www-mechanize-cached/Cached.pm,v 1.18 2004/04/12 03:21:25 andy Exp $
 
 =cut
 
 use vars qw( $VERSION );
-$VERSION = '1.30';
+$VERSION = '1.32';
 
-=head1 SYNOPSIS
+=head1 Synopsis
 
     use WWW::Mechanize::Cached;
 
     my $cacher = WWW::Mechanize::Cached->new;
     $cacher->get( $url );
 
-=head1 DESCRIPTION
+=head1 Description
 
 Uses the L<Cache::Cache> hierarchy to implement a caching Mech. This
 lets one perform repeated requests without hammering a server impolitely.
@@ -38,7 +38,7 @@ use Storable qw( freeze thaw );
 
 my $cache_key = __PACKAGE__;
 
-=head1 CONSTRUCTOR
+=head1 Constructor
 
 =head2 new
 
@@ -85,40 +85,53 @@ sub new {
     return $self;
 }
 
-=head1 METHODS
+=head1 Methods
 
-All methods are provided by L<WWW::Mechanize>. See that module's
+Most methods are provided by L<WWW::Mechanize>. See that module's
 documentation for details.
 
+=head2 is_cached()
+
+Returns true if the current page is from the cache, or false if not.
+If it returns C<undef>, then you don't have any current request.
+
 =cut
 
+sub is_cached {
+    my $self = shift;
+
+    return $self->{_is_cached};
+}
+
 sub _make_request {
     my $self = shift;
     my $request = shift;
 
     my $req = $request->as_string;
     my $cache = $self->{$cache_key};
-    my $v = $cache->get( $req );
-    if ($v) {
-        $v = thaw $v;
+    my $response= $cache->get( $req );
+    if ( $response ) {
+        $response = thaw $response;
+        $self->{_is_cached} = 1;
     } else {
-        $v = $self->SUPER::_make_request( $request, @_ );
-        $cache->set( $req, freeze($v) );
-    };
+        $response = $self->SUPER::_make_request( $request, @_ );
+        $cache->set( $req, freeze($response) );
+        $self->{_is_cached} = 0;
+    }
 
     # An odd line to need.
     $self->{proxy} = {} unless defined $self->{proxy};
 
-    return $v;
+    return $response;
 }
 
 
 
-=head1 THANKS
+=head1 Thanks
 
-Andy Lester (PETDANCE) for L<WWW::Mechanize>.
+Iain Truskett for writing this in the first place.
 
-=head1 ODDITIES
+=head1 Oddities
 
 It may sometimes seem as if it's not caching something. And this
 may well be true. It uses the HTTP request, in string form, as the key
@@ -126,7 +139,7 @@ to the cache entries, so any minor changes will result in a different
 key. This is most noticable when following links as L<WWW::Mechanize>
 adds a C<Referer> header.
 
-=head1 BUGS, REQUESTS, COMMENTS
+=head1 Bugs, Requests, Comments
 
 Support for this module is provided via the CPAN RT system:
 
@@ -137,7 +150,7 @@ Support for this module is provided via the CPAN RT system:
 This makes it much easier for me to track things and thus means
 your problem is less likely to be neglected.
 
-=head1 LICENCE AND COPYRIGHT
+=head1 Licence and copyright
 
 This module is copyright Iain Truskett and Andy Lester, 2004. All rights
 reserved.
@@ -150,12 +163,12 @@ The full text of the licences can be found in the F<Artistic> and
 F<COPYING> files included with this module, or in L<perlartistic> and
 L<perlgpl> as supplied with Perl 5.8.1 and later.
 
-=head1 AUTHOR
+=head1 Author
 
 Iain Truskett <spoon@cpan.org>, currently maintained by Andy Lester
 <petdance@cpan.org>
 
-=head1 SEE ALSO
+=head1 See also
 
 L<perl>, L<WWW::Mechanize>.
 
